@@ -1,9 +1,9 @@
 package WWW::Hetzner::CLI::Cmd::Server::Cmd::Poweron;
-our $VERSION = '0.001';
 our $AUTHORITY = 'cpan:GETTY';
-
 # ABSTRACT: Power on a server
 
+our $VERSION = '0.002';
+
 use Moo;
 use MooX::Cmd;
 use MooX::Options protect_argv => 0, usage_string => 'USAGE: hcloud.pl server poweron <id>';
@@ -34,21 +34,22 @@ WWW::Hetzner::CLI::Cmd::Server::Cmd::Poweron - Power on a server
 
 =head1 VERSION
 
-version 0.001
-
-=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+version 0.002
 
 =head1 SUPPORT
 
-=head2 Source Code
+=head2 Issues
 
-The code is open to the world, and available for you to hack on. Please feel free to browse it and play
-with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
-from your repository :)
+Please report bugs and feature requests on GitHub at
+L<https://github.com/Getty/p5-www-hetzner/issues>.
 
-L<https://github.com/Getty/p5-www-hetzner>
+=head2 IRC
 
-  git clone https://github.com/Getty/p5-www-hetzner.git
+Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.
+
+=head1 CONTRIBUTING
+
+Contributions are welcome! Please fork the repository and submit a pull request.
 
 =head1 AUTHOR
 
